======================
Contributing to Bowtie
======================

Interested in contributing to Bowtie?

That would be incredibly appreciated.

A contributor's guide can be found in Bowtie's documentation [here](https://docs.bowtie.report/en/stable/contributing/).
It contains information about how to develop on Bowtie's internals, as well as some things you should be aware of when making contributions.
Hopefully the former you'll find useful, and the latter even if boring is nonetheless important to understand.
Nothing in the contributor's guide should be terribly different from the norm, but please do flip through it as any contribution you make definitely assumes you have read through it at least once.
